/**
 * Copyright 2012 the project-owners
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package inti.util;

import java.io.IOException;
import java.io.OutputStream;

/**
 * OutputStream which notifies on writes and closes.
 */
public class NotifyingOutputStream extends OutputStream {
    
    /**
     * Notifier interface for output streams.
     */
    public interface WriteNotifier {
        
        void write(int b);
        
        void write(byte[] data, int offset, int length);
        
        void close();
        
    }
    
    OutputStream destination;
    WriteNotifier notifier;
    
    @Override
    public void write(int b) throws IOException {
        notifier.write(b);
        destination.write(b);
    }
    
    @Override
    public void write(byte[] b, int off, int len) throws IOException {
        notifier.write(b, off, len);
        destination.write(b, off, len);
    }
    
    @Override
    public void flush() throws IOException {
        destination.flush();
    }
    
    @Override
    public void close() throws IOException {
        notifier.close();
        destination.close();
    }
    
    public OutputStream getDestination() {
        return destination;
    }
    
    public void setDestination(OutputStream destination) {
        this.destination = destination;
    }
    
    public WriteNotifier getNotifier() {
        return notifier;
    }
    
    public void setNotifier(WriteNotifier notifier) {
        this.notifier = notifier;
    }
    
}
