/**
 * Copyright 2012 the project-owners
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package inti.util;

import java.nio.ByteBuffer;

/**
 * An utility for common string operations.
 */
public class StringUtil {
    
    /**
     * A fast byte-to-string implementation which allocates only the new string object.
     * 
     * @param data The string data as single-byte values.
     * @param offset The offset in the data-array.
     * @param length The byte count to cast to character.
     * @param buffer The transfer buffer used to cast.
     * @return The newly-created string.
     */
    public String bytesToString(byte[] data, int offset, int length, char[] buffer) {
        for (int i = offset, j = 0; i < length; i++, j++) {
            buffer[j] = (char) data[i];
        }
        return String.valueOf(buffer, 0, length);
    }
    
    /**
     * A fast string-to-byte implementation which allocates no new objects at all.
     * 
     * @param source The string source as single-byte values.
     * @param dest The buffer to write the string data to.
     */
    public void stringToBytes(String source, ByteBuffer dest) {
        for (int i = 0; i < source.length(); i++) {
            dest.put((byte) source.charAt(i));
        }
    }
    
}